==> apache-asterixdb-0.9.7-source-release.zip: apache-asterixdb-0.9.7/asterix-lang-common/src/main/java/org/apache/asterix/lang/common/statement/UpsertStatement.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.asterix.lang.common.statement;

import org.apache.asterix.common.metadata.DataverseName;
import org.apache.asterix.lang.common.base.Expression;
import org.apache.asterix.lang.common.base.Statement;
import org.apache.asterix.lang.common.expression.VariableExpr;

public class UpsertStatement extends InsertStatement {

    public UpsertStatement(DataverseName dataverseName, String datasetName, Query query, int varCounter,
            VariableExpr var, Expression returnExpression) {
        super(dataverseName, datasetName, query, varCounter, var, returnExpression);
    }

    @Override
    public Kind getKind() {
        return Statement.Kind.UPSERT;
    }

    @Override
    public int hashCode() {
        return 31 * super.hashCode() + Statement.Kind.UPSERT.hashCode();
    }

    @Override
    public boolean equals(Object object) {
        return this == object || object instanceof UpsertStatement && super.equals(object);
    }

}

==> apache-asterixdb-0.9.9-source-release.zip: apache-asterixdb-0.9.9/asterix-lang-common/src/main/java/org/apache/asterix/lang/common/statement/UpsertStatement.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.asterix.lang.common.statement;

import org.apache.asterix.common.metadata.Namespace;
import org.apache.asterix.lang.common.base.Expression;
import org.apache.asterix.lang.common.base.Statement;
import org.apache.asterix.lang.common.expression.VariableExpr;

public class UpsertStatement extends InsertStatement {

    public UpsertStatement(Namespace namespace, String datasetName, Query query, int varCounter, VariableExpr var,
            Expression returnExpression) {
        super(namespace, datasetName, query, varCounter, var, returnExpression);
    }

    @Override
    public Kind getKind() {
        return Statement.Kind.UPSERT;
    }

    @Override
    public int hashCode() {
        return 31 * super.hashCode() + Statement.Kind.UPSERT.hashCode();
    }

    @Override
    public boolean equals(Object object) {
        return this == object || object instanceof UpsertStatement && super.equals(object);
    }

}
